@@ -25,14 +25,6 @@ class ComparisonOperatorError(InterpreterError):
     """Use to capture error for invalid comparison operator"""
 
 
-class ConnectDataStatementError(InterpreterError):
-    """Use to capture error for interpreting connect data statement"""
-
-
-class UseTestcaseStatementError(InterpreterError):
-    """Use to capture error for interpreting use testcase statement"""
-
-
 class ConnectDeviceStatementError(InterpreterError):
     """Use to capture error for interpreting connect device statement"""
 
@@ -45,10 +37,6 @@ class ReleaseDeviceStatementError(InterpreterError):
     """Use to capture error for interpreting release device statement"""
 
 
-class ReleaseResourceStatementError(InterpreterError):
-    """Use to capture error for interpreting release resource statement"""
-
-
 class WaitForStatementError(InterpreterError):
     """Use to capture error for interpreting wait for statement"""
 
@@ -60,5 +48,18 @@ class PerformerStatementError(InterpreterError):
 class VerificationStatementError(InterpreterError):
     """Use to capture error for verification statement"""
 
+
 class ScriptBuilderError(InterpreterError):
     """Use to capture error for building test script"""
+
+
+class DurationArgumentError(InterpreterError):
+    """Use to capture error for wait_for function"""
+
+
+class ConvertorTypeError(InterpreterError):
+    """Use to capture convertor argument for filter method"""
+
+
+class TemplateReferenceError(InterpreterError):
+    """Use to capture template reference for filter method"""
