@@ -58,21 +58,11 @@ class CheckStatement:
         match = re.match(r'(?i) *(sleeps?|(wait +for)) +', data)
         return bool(match)
 
-    @classmethod
-    def is_connect_data_statement(cls, data):
-        match = re.match(r'(?i) *connects? +data +', data)
-        return bool(match)
-
     @classmethod
     def is_connect_device_statement(cls, data):
         match = re.match(r'(?i) *connects? +device +', data)
         return bool(match)
 
-    @classmethod
-    def is_use_testcase_statement(cls, data):
-        match = re.match(r'(?i) *uses? +testcase +', data)
-        return bool(match)
-
     @classmethod
     def is_disconnect_device_statement(cls, data):
         match = re.match(r'(?i) *disconnects?( +device)? +', data)
@@ -83,11 +73,6 @@ class CheckStatement:
         match = re.match(r'(?i) *releases? +device +', data)
         return bool(match)
 
-    @classmethod
-    def is_release_resource_statement(cls, data):
-        match = re.match(r'(?i) *releases? +resource +', data)
-        return bool(match)
-
     @classmethod
     def is_dummy_statement(cls, data):
         match = re.match(r'(?i) *dummy[_. -]*(pass|fail)', data)
@@ -118,21 +103,11 @@ class CheckStatement:
         chk = cls.is_pausing_statement(data) and data.startswith(' ')
         return chk
 
-    @classmethod
-    def is_child_connect_data_statement(cls, data):
-        chk = cls.is_connect_data_statement(data) and data.startswith(' ')
-        return chk
-
     @classmethod
     def is_child_connect_device_statement(cls, data):
         chk = cls.is_connect_device_statement(data) and data.startswith(' ')
         return chk
 
-    @classmethod
-    def is_child_use_testcase_statement(cls, data):
-        chk = cls.is_use_testcase_statement(data) and data.startswith(' ')
-        return chk
-
     @classmethod
     def is_child_disconnect_device_statement(cls, data):
         chk = cls.is_disconnect_device_statement(data) and data.startswith(' ')
@@ -143,11 +118,6 @@ class CheckStatement:
         chk = cls.is_release_device_statement(data) and data.startswith(' ')
         return chk
 
-    @classmethod
-    def is_child_release_resource_statement(cls, data):
-        chk = cls.is_release_resource_statement(data) and data.startswith(' ')
-        return chk
-
     @classmethod
     def is_child_dummy_statement(cls, data):
         chk = cls.is_dummy_statement(data) and data.startswith(' ')
